#!/usr/bin/env python3

from __future__ import absolute_import
from CloudflareAPI.cloudflare import Cloudflare
from CloudflareAPI.utils import Fetch, wait_result


__ALL__ = ["Cloudflare", "Fetch", "wait_result"]
